==> haskell-async-2.1.1.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-async.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: async
version: 2.1.1.1
id: async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc
key: async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc
license: BSD3
copyright: (c) Simon Marlow 2012
maintainer: Simon Marlow <marlowsd@gmail.com>
homepage: https://github.com/simonmar/async
synopsis: Run IO operations asynchronously and wait for their results
description:
    This package provides a higher-level interface over
    threads, in which an @Async a@ is a concurrent
    thread that will eventually deliver a value of
    type @a@.  The package provides ways to create
    @Async@ computations, wait for their results, and
    cancel them.
    .
    Using @Async@ is safer than using threads in two
    ways:
    .
    * When waiting for a thread to return a result,
    if the thread dies with an exception then the
    caller must either re-throw the exception
    ('\''wait'\'') or handle it ('\''waitCatch'\''); the
    exception cannot be ignored.
    .
    * The API makes it possible to build a tree of
    threads that are automatically killed when
    their parent dies (see '\''withAsync'\'').
category: Concurrency
author: Simon Marlow
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Async
abi: 4ad1a36fd79247fdbaa53c120c46b6d7
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/async-2.1.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/async-2.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/async-2.1.1.1
hs-libraries: HSasync-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc
depends:
    base-4.10.0.0 stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ=a88f5bbac4be96a38c5ca2a658c158a0
haddock-interfaces: /usr/share/doc/haskell-async/html/async.haddock
haddock-html: /usr/share/doc/haskell-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-async-2.1.1.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-async.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: async
version: 2.1.1.1
id: async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn
key: async-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn
license: BSD3
copyright: (c) Simon Marlow 2012
maintainer: Simon Marlow <marlowsd@gmail.com>
homepage: https://github.com/simonmar/async
synopsis: Run IO operations asynchronously and wait for their results
description:
    This package provides a higher-level interface over
    threads, in which an @Async a@ is a concurrent
    thread that will eventually deliver a value of
    type @a@.  The package provides ways to create
    @Async@ computations, wait for their results, and
    cancel them.
    .
    Using @Async@ is safer than using threads in two
    ways:
    .
    * When waiting for a thread to return a result,
    if the thread dies with an exception then the
    caller must either re-throw the exception
    ('\''wait'\'') or handle it ('\''waitCatch'\''); the
    exception cannot be ignored.
    .
    * The API makes it possible to build a tree of
    threads that are automatically killed when
    their parent dies (see '\''withAsync'\'').
category: Concurrency
author: Simon Marlow
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Async
abi: 7d406f0044aa7af43d5b6fcf63e521db
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/async-2.1.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/async-2.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/async-2.1.1.1
hs-libraries: HSasync-2.1.1.1-K5IvYqkVegLI7CBS6i3gtn
depends:
    base-4.10.1.0 stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw=63c518eabfb1b430d925fb35cc544a7c
haddock-interfaces: /usr/share/doc/haskell-async/html/async.haddock
haddock-html: /usr/share/doc/haskell-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
